Pipeline
========

.. image:: https://secure.travis-ci.org/jazzband/django-pipeline.png
    :alt: Build Status
    :target: http://travis-ci.org/jazzband/django-pipeline

.. image:: https://jazzband.co/static/img/badge.svg
   :alt: Jazzband
   :target: https://jazzband.co/

Pipeline is an asset packaging library for Django, providing both CSS and
JavaScript concatenation and compression, built-in JavaScript template support,
and optional data-URI image and font embedding.


Installation
------------

To install it, simply: ::

    pip install django-pipeline


Documentation
-------------

For documentation, usage, and examples, see :
https://django-pipeline.readthedocs.org
